@@ -103,7 +103,7 @@ END IF;
 FOREACH v_id IN ARRAY p_partition_ids LOOP
 -- Do not create the child table if it's outside the bounds of the top parent. 
     IF v_sub_id_min IS NOT NULL THEN
-        IF v_id < v_sub_id_min OR v_id > v_sub_id_max THEN
+        IF v_id < v_sub_id_min OR v_id >= v_sub_id_max THEN
             CONTINUE;
         END IF;
     END IF;
@@ -265,6 +265,7 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
             , sub_inherit_privileges
             , sub_constraint_valid
             , sub_subscription_refresh
+            , sub_date_trunc_interval
         FROM @extschema@.part_config_sub
         WHERE sub_parent = p_parent_table
     LOOP
@@ -283,7 +284,8 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
                 , p_epoch := %L
                 , p_template_table := %L
                 , p_jobmon := %L
-                , p_start_partition := %L )'
+                , p_start_partition := %L 
+                , p_date_trunc_interval := %L )'
             , v_parent_schema||'.'||v_partition_name
             , v_row.sub_control
             , v_row.sub_partition_type
@@ -295,7 +297,8 @@ FOREACH v_id IN ARRAY p_partition_ids LOOP
             , v_row.sub_epoch
             , v_row.sub_template_table
             , v_row.sub_jobmon
-            , p_start_partition);
+            , p_start_partition
+            , v_row.sub_date_trunc_interval);
         RAISE DEBUG 'create_partition_id (create_parent loop): %', v_sql;
         EXECUTE v_sql;
 
