@@ -4,12 +4,15 @@ CREATE FUNCTION @extschema@.partition_data_id(p_parent_table text
     , p_lock_wait numeric DEFAULT 0
     , p_order text DEFAULT 'ASC'
     , p_analyze boolean DEFAULT true
-    , p_source_table text DEFAULT NULL) 
+    , p_source_table text DEFAULT NULL
+    , p_ignored_columns text[] DEFAULT NULL) 
 RETURNS bigint
 LANGUAGE plpgsql
 AS $$
 DECLARE
 
+v_col                       text;
+v_column_list               text;
 v_control                   text;
 v_control_type              text;
 v_current_partition_name    text;
@@ -99,6 +102,7 @@ ELSIF v_partition_type = 'native' AND current_setting('server_version_num')::int
         , v_source_tablename);
 
     EXECUTE v_sql INTO v_default_schemaname, v_default_tablename;
+
     IF v_default_tablename IS NOT NULL THEN
         v_source_schemaname := v_default_schemaname;
         v_source_tablename := v_default_tablename;
@@ -119,6 +123,25 @@ IF p_batch_interval IS NULL OR p_batch_interval > v_partition_interval THEN
     p_batch_interval := v_partition_interval;
 END IF;
 
+-- Generate column list to use in SELECT/INSERT statements below. Allows for exclusion of GENERATED (or any other desired) columns.
+v_sql := format ('SELECT ''"''||string_agg(attname, ''","'')||''"'' FROM pg_catalog.pg_attribute a
+                    JOIN pg_catalog.pg_class c ON a.attrelid = c.oid
+                    JOIN pg_catalog.pg_namespace n ON c.relnamespace = n.oid
+                    WHERE n.nspname = %L
+                    AND c.relname = %L 
+                    AND a.attnum > 0 
+                    AND a.attisdropped = false'
+                  , v_source_schemaname
+                  , v_source_tablename);
+
+IF p_ignored_columns IS NOT NULL THEN
+    FOREACH v_col IN ARRAY p_ignored_columns LOOP
+        v_sql := v_sql || format(' AND attname != %L ', v_col);
+    END LOOP;
+END IF;
+
+EXECUTE v_sql INTO v_column_list;
+
 FOR i IN 1..p_batch_count LOOP
 
     IF p_order = 'ASC' THEN
@@ -158,7 +181,8 @@ FOR i IN 1..p_batch_count LOOP
         WHILE v_lock_iter <= 5 LOOP
             v_lock_iter := v_lock_iter + 1;
             BEGIN
-                v_sql := format('SELECT * FROM ONLY %I.%I WHERE %I >= %s AND %I < %s FOR UPDATE NOWAIT'
+                v_sql := format('SELECT %s FROM ONLY %I.%I WHERE %I >= %s AND %I < %s FOR UPDATE NOWAIT'
+                    , v_column_list
                     , v_source_schemaname
                     , v_source_tablename
                     , v_control
@@ -189,20 +213,22 @@ IF v_default_exists THEN
     -- Temp table created above to avoid excessive temp creation in loop
     EXECUTE format('WITH partition_data AS (
             DELETE FROM %1$I.%2$I WHERE %3$I >= %4$s AND %3$I < %5$s RETURNING *)
-        INSERT INTO partman_temp_data_storage SELECT * FROM partition_data'
+        INSERT INTO partman_temp_data_storage (%6$s) SELECT %6$s FROM partition_data'
         , v_source_schemaname
         , v_source_tablename
         , v_control
         , v_min_partition_id
-        , v_max_partition_id);
+        , v_max_partition_id
+        , v_column_list);
 
     PERFORM @extschema@.create_partition_id(p_parent_table, v_partition_id, p_analyze);
 
     EXECUTE format('WITH partition_data AS (
             DELETE FROM partman_temp_data_storage RETURNING *)
-        INSERT INTO %I.%I SELECT * FROM partition_data'
+        INSERT INTO %1$I.%2$I (%3$s) SELECT %3$s FROM partition_data'
         , v_source_schemaname
-        , v_current_partition_name);
+        , v_current_partition_name
+        , v_column_list);
 
 
 ELSE
@@ -211,13 +237,14 @@ ELSE
 
     EXECUTE format('WITH partition_data AS (
             DELETE FROM ONLY %1$I.%2$I WHERE %3$I >= %4$s AND %3$I < %5$s RETURNING *)
-        INSERT INTO %1$I.%6$I SELECT * FROM partition_data'
+        INSERT INTO %1$I.%6$I (%7$s) SELECT %7$s FROM partition_data'
         , v_source_schemaname
         , v_source_tablename
         , v_control
         , v_min_partition_id
         , v_max_partition_id
-        , v_current_partition_name);
+        , v_current_partition_name
+        , v_column_list);
 
 END IF;
 
